<?php
/**
 * The Header: Logo and main menu
 *
 * @package VEIL
 * @since VEIL 1.0
 */
?><!DOCTYPE html>
<html <?php language_attributes(); ?> class="no-js<?php
	// Class scheme_xxx need in the <html> as context for the <body>!
	echo ' scheme_' . esc_attr( veil_get_theme_option( 'color_scheme' ) );
?>">

<head>
	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>

	<?php
	if ( function_exists( 'wp_body_open' ) ) {
		wp_body_open();
	} else {
		do_action( 'wp_body_open' );
	}
	do_action( 'veil_action_before_body' );
	?>

	<div class="<?php echo esc_attr( apply_filters( 'veil_filter_body_wrap_class', 'body_wrap' ) ); ?>" <?php do_action('veil_action_body_wrap_attributes'); ?>>

		<?php do_action( 'veil_action_before_page_wrap' ); ?>

		<div class="<?php echo esc_attr( apply_filters( 'veil_filter_page_wrap_class', 'page_wrap' ) ); ?>" <?php do_action('veil_action_page_wrap_attributes'); ?>>

			<?php do_action( 'veil_action_page_wrap_start' ); ?>

			<?php
			$veil_full_post_loading = ( veil_is_singular( 'post' ) || veil_is_singular( 'attachment' ) ) && veil_get_value_gp( 'action' ) == 'full_post_loading';
			$veil_prev_post_loading = ( veil_is_singular( 'post' ) || veil_is_singular( 'attachment' ) ) && veil_get_value_gp( 'action' ) == 'prev_post_loading';

			// Don't display the header elements while actions 'full_post_loading' and 'prev_post_loading'
			if ( ! $veil_full_post_loading && ! $veil_prev_post_loading ) {

				// Short links to fast access to the content, sidebar and footer from the keyboard
				?>
				<a class="veil_skip_link skip_to_content_link" href="#content_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'veil_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to content", 'veil' ); ?></a>
				<?php if ( veil_sidebar_present() ) { ?>
				<a class="veil_skip_link skip_to_sidebar_link" href="#sidebar_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'veil_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to sidebar", 'veil' ); ?></a>
				<?php } ?>
				<a class="veil_skip_link skip_to_footer_link" href="#footer_skip_link_anchor" tabindex="<?php echo esc_attr( apply_filters( 'veil_filter_skip_links_tabindex', 1 ) ); ?>"><?php esc_html_e( "Skip to footer", 'veil' ); ?></a>

				<?php
				do_action( 'veil_action_before_header' );

				// Header
				$veil_header_type = veil_get_theme_option( 'header_type' );
				if ( 'custom' == $veil_header_type && ! veil_is_layouts_available() ) {
					$veil_header_type = 'default';
				}
				get_template_part( apply_filters( 'veil_filter_get_template_part', "templates/header-" . sanitize_file_name( $veil_header_type ) ) );

				// Side menu
				if ( in_array( veil_get_theme_option( 'menu_side' ), array( 'left', 'right' ) ) ) {
					get_template_part( apply_filters( 'veil_filter_get_template_part', 'templates/header-navi-side' ) );
				}

				// Mobile menu
				get_template_part( apply_filters( 'veil_filter_get_template_part', 'templates/header-navi-mobile' ) );

				do_action( 'veil_action_after_header' );

			}
			?>

			<?php do_action( 'veil_action_before_page_content_wrap' ); ?>

			<div class="page_content_wrap<?php
				if ( veil_is_off( veil_get_theme_option( 'remove_margins' ) ) ) {
					if ( empty( $veil_header_type ) ) {
						$veil_header_type = veil_get_theme_option( 'header_type' );
					}
					if ( 'custom' == $veil_header_type && veil_is_layouts_available() ) {
						$veil_header_id = veil_get_custom_header_id();
						if ( $veil_header_id > 0 ) {
							$veil_header_meta = veil_get_custom_layout_meta( $veil_header_id );
							if ( ! empty( $veil_header_meta['margin'] ) ) {
								?> page_content_wrap_custom_header_margin<?php
							}
						}
					}
					$veil_footer_type = veil_get_theme_option( 'footer_type' );
					if ( 'custom' == $veil_footer_type && veil_is_layouts_available() ) {
						$veil_footer_id = veil_get_custom_footer_id();
						if ( $veil_footer_id ) {
							$veil_footer_meta = veil_get_custom_layout_meta( $veil_footer_id );
							if ( ! empty( $veil_footer_meta['margin'] ) ) {
								?> page_content_wrap_custom_footer_margin<?php
							}
						}
					}
				}
				do_action( 'veil_action_page_content_wrap_class', $veil_prev_post_loading );
				?>"<?php
				if ( apply_filters( 'veil_filter_is_prev_post_loading', $veil_prev_post_loading ) ) {
					?> data-single-style="<?php echo esc_attr( veil_get_theme_option( 'single_style' ) ); ?>"<?php
				}
				do_action( 'veil_action_page_content_wrap_data', $veil_prev_post_loading );
			?>>
				<?php
				do_action( 'veil_action_page_content_wrap', $veil_full_post_loading || $veil_prev_post_loading );

				// Single posts banner
				if ( apply_filters( 'veil_filter_single_post_header', veil_is_singular( 'post' ) || veil_is_singular( 'attachment' ) ) ) {
					if ( $veil_prev_post_loading ) {
						if ( veil_get_theme_option( 'posts_navigation_scroll_which_block' ) != 'article' ) {
							do_action( 'veil_action_between_posts' );
						}
					}
					// Single post thumbnail and title
					$veil_path = apply_filters( 'veil_filter_get_template_part', 'templates/single-styles/' . veil_get_theme_option( 'single_style' ) );
					if ( veil_get_file_dir( $veil_path . '.php' ) != '' ) {
						get_template_part( $veil_path );
					}
				}

				// Widgets area above page
				$veil_body_style   = veil_get_theme_option( 'body_style' );
				$veil_widgets_name = veil_get_theme_option( 'widgets_above_page' );
				$veil_show_widgets = ! veil_is_off( $veil_widgets_name ) && is_active_sidebar( $veil_widgets_name );
				if ( $veil_show_widgets ) {
					if ( 'fullscreen' != $veil_body_style ) {
						?>
						<div class="content_wrap">
							<?php
					}
					veil_create_widgets_area( 'widgets_above_page' );
					if ( 'fullscreen' != $veil_body_style ) {
						?>
						</div>
						<?php
					}
				}

				// Content area
				do_action( 'veil_action_before_content_wrap' );
				?>
				<div class="content_wrap<?php echo 'fullscreen' == $veil_body_style ? '_fullscreen' : ''; ?>">

					<?php do_action( 'veil_action_content_wrap_start' ); ?>

					<div class="content">
						<?php
						do_action( 'veil_action_page_content_start' );

						// Skip link anchor to fast access to the content from keyboard
						?>
						<a id="content_skip_link_anchor" class="veil_skip_link_anchor" href="#"></a>
						<?php
						// Single posts banner between prev/next posts
						if ( ( veil_is_singular( 'post' ) || veil_is_singular( 'attachment' ) )
							&& $veil_prev_post_loading 
							&& veil_get_theme_option( 'posts_navigation_scroll_which_block' ) == 'article'
						) {
							do_action( 'veil_action_between_posts' );
						}

						// Widgets area above content
						veil_create_widgets_area( 'widgets_above_content' );

						do_action( 'veil_action_page_content_start_text' );
