<?php
/**
 * The main template file.
 *
 * This is the most generic template file in a WordPress theme
 * and one of the two required files for a theme (the other being style.css).
 * It is used to display a page when nothing more specific matches a query.
 * E.g., it puts together the home page when no home.php file exists.
 * Learn more: //codex.wordpress.org/Template_Hierarchy
 *
 * @package VEIL
 * @since VEIL 1.0
 */

$veil_template = apply_filters( 'veil_filter_get_template_part', veil_blog_archive_get_template() );

if ( ! empty( $veil_template ) && 'index' != $veil_template ) {

	get_template_part( $veil_template );

} else {

	veil_storage_set( 'blog_archive', true );

	get_header();

	if ( have_posts() ) {

		// Query params
		$veil_stickies   = is_home()
								|| ( in_array( veil_get_theme_option( 'post_type' ), array( '', 'post' ) )
									&& (int) veil_get_theme_option( 'parent_cat' ) == 0
									)
										? get_option( 'sticky_posts' )
										: false;
		$veil_post_type  = veil_get_theme_option( 'post_type' );
		$veil_args       = array(
								'blog_style'     => veil_get_theme_option( 'blog_style' ),
								'post_type'      => $veil_post_type,
								'taxonomy'       => veil_get_post_type_taxonomy( $veil_post_type ),
								'parent_cat'     => veil_get_theme_option( 'parent_cat' ),
								'posts_per_page' => veil_get_theme_option( 'posts_per_page' ),
								'sticky'         => veil_get_theme_option( 'sticky_style' ) == 'columns'
															&& is_array( $veil_stickies )
															&& count( $veil_stickies ) > 0
															&& get_query_var( 'paged' ) < 1
								);

		veil_blog_archive_start();

		do_action( 'veil_action_blog_archive_start' );

		if ( is_author() ) {
			do_action( 'veil_action_before_page_author' );
			get_template_part( apply_filters( 'veil_filter_get_template_part', 'templates/author-page' ) );
			do_action( 'veil_action_after_page_author' );
		}

		if ( veil_get_theme_option( 'show_filters' ) ) {
			do_action( 'veil_action_before_page_filters' );
			veil_show_filters( $veil_args );
			do_action( 'veil_action_after_page_filters' );
		} else {
			do_action( 'veil_action_before_page_posts' );
			veil_show_posts( array_merge( $veil_args, array( 'cat' => $veil_args['parent_cat'] ) ) );
			do_action( 'veil_action_after_page_posts' );
		}

		do_action( 'veil_action_blog_archive_end' );

		veil_blog_archive_end();

	} else {

		if ( is_search() ) {
			get_template_part( apply_filters( 'veil_filter_get_template_part', 'templates/content', 'none-search' ), 'none-search' );
		} else {
			get_template_part( apply_filters( 'veil_filter_get_template_part', 'templates/content', 'none-archive' ), 'none-archive' );
		}
	}

	get_footer();
}
