<?php
/**
 * The Sidebar containing the main widget areas.
 *
 * @package VEIL
 * @since VEIL 1.0
 */

if ( veil_sidebar_present() ) {
	
	$veil_sidebar_type = veil_get_theme_option( 'sidebar_type' );
	if ( 'custom' == $veil_sidebar_type && ! veil_is_layouts_available() ) {
		$veil_sidebar_type = 'default';
	}
	
	// Catch output to the buffer
	ob_start();
	if ( 'default' == $veil_sidebar_type ) {
		// Default sidebar with widgets
		$veil_sidebar_name = veil_get_theme_option( 'sidebar_widgets' );
		veil_storage_set( 'current_sidebar', 'sidebar' );
		if ( is_active_sidebar( $veil_sidebar_name ) ) {
			dynamic_sidebar( $veil_sidebar_name );
		}
	} else {
		// Custom sidebar from Layouts Builder
		$veil_sidebar_id = veil_get_custom_sidebar_id();
		do_action( 'veil_action_show_layout', $veil_sidebar_id );
	}
	$veil_out = trim( ob_get_contents() );
	ob_end_clean();
	
	// If any html is present - display it
	if ( ! empty( $veil_out ) ) {
		$veil_sidebar_position    = veil_get_theme_option( 'sidebar_position' );
		$veil_sidebar_position_ss = veil_get_theme_option( 'sidebar_position_ss' );
		?>
		<div class="sidebar widget_area
			<?php
			echo ' ' . esc_attr( $veil_sidebar_position );
			echo ' sidebar_' . esc_attr( $veil_sidebar_position_ss );
			echo ' sidebar_' . esc_attr( $veil_sidebar_type );

			$veil_sidebar_scheme = apply_filters( 'veil_filter_sidebar_scheme', veil_get_theme_option( 'sidebar_scheme' ) );
			if ( ! empty( $veil_sidebar_scheme ) && ! veil_is_inherit( $veil_sidebar_scheme ) && 'custom' != $veil_sidebar_type ) {
				echo ' scheme_' . esc_attr( $veil_sidebar_scheme );
			}
			?>
		" role="complementary">
			<?php

			// Skip link anchor to fast access to the sidebar from keyboard
			?>
			<a id="sidebar_skip_link_anchor" class="veil_skip_link_anchor" href="#"></a>
			<?php

			do_action( 'veil_action_before_sidebar_wrap', 'sidebar' );

			// Button to show/hide sidebar on mobile
			if ( in_array( $veil_sidebar_position_ss, array( 'above', 'float' ) ) ) {
				$veil_title = apply_filters( 'veil_filter_sidebar_control_title', 'float' == $veil_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'veil' ) : '' );
				$veil_text  = apply_filters( 'veil_filter_sidebar_control_text', 'above' == $veil_sidebar_position_ss ? esc_html__( 'Show Sidebar', 'veil' ) : '' );
				?>
				<a href="#" class="sidebar_control" title="<?php echo esc_attr( $veil_title ); ?>"><?php echo esc_html( $veil_text ); ?></a>
				<?php
			}
			?>
			<div class="sidebar_inner">
				<?php
				do_action( 'veil_action_before_sidebar', 'sidebar' );
				veil_show_layout( preg_replace( "/<\/aside>[\r\n\s]*<aside/", '</aside><aside', $veil_out ) );
				do_action( 'veil_action_after_sidebar', 'sidebar' );
				?>
			</div>
			<?php

			do_action( 'veil_action_after_sidebar_wrap', 'sidebar' );

			?>
		</div>
		<div class="clearfix"></div>
		<?php
	}
}
