<?php
/**
 * Skin Setup
 *
 * @package VEIL
 * @since VEIL 1.76.0
 */


//--------------------------------------------
// SKIN DEFAULTS
//--------------------------------------------

// Return theme's (skin's) default value for the specified parameter
if ( ! function_exists( 'veil_theme_defaults' ) ) {
	function veil_theme_defaults( $name='', $value='' ) {
		$defaults = array(
			'page_width'          => 1290,
			'page_boxed_extra'  => 60,
			'page_fullwide_max' => 1920,
			'page_fullwide_extra' => 60,
			'sidebar_width'       => 410,
			'sidebar_gap'       => 40,
			'grid_gap'          => 30,
			'rad'               => 0
		);
		if ( empty( $name ) ) {
			return $defaults;
		} else {
			if ( $value === '' && isset( $defaults[ $name ] ) ) {
				$value = $defaults[ $name ];
			}
			return $value;
		}
	}
}


// WOOCOMMERCE SETUP
//--------------------------------------------------

// Allow extended layouts for WooCommerce
if ( ! function_exists( 'veil_skin_woocommerce_allow_extensions' ) ) {
	add_filter( 'veil_filter_load_woocommerce_extensions', 'veil_skin_woocommerce_allow_extensions' );
	function veil_skin_woocommerce_allow_extensions( $allow ) {
		return false;
	}
}


// Theme init priorities:
// Action 'after_setup_theme'
// 1 - register filters to add/remove lists items in the Theme Options
// 2 - create Theme Options
// 3 - add/remove Theme Options elements
// 5 - load Theme Options. Attention! After this step you can use only basic options (not overriden)
// 9 - register other filters (for installer, etc.)
//10 - standard Theme init procedures (not ordered)
// Action 'wp_loaded'
// 1 - detect override mode. Attention! Only after this step you can use overriden options (separate values for the shop, courses, etc.)


//--------------------------------------------
// SKIN SETTINGS
//--------------------------------------------
if ( ! function_exists( 'veil_skin_setup' ) ) {
	add_action( 'after_setup_theme', 'veil_skin_setup', 1 );
	function veil_skin_setup() {

		$GLOBALS['VEIL_STORAGE'] = array_merge( $GLOBALS['VEIL_STORAGE'], array(

			// Key validator: market[env|loc]-vendor[axiom|ancora|themerex]
			'theme_pro_key'       => 'env-ancora',

			'theme_doc_url'       => '//veil.ancorathemes.com/doc',

			'theme_demofiles_url' => '//demofiles.ancorathemes.com/veil/',
			
			'theme_rate_url'      => '//themeforest.net/download',

			'theme_custom_url'    => '//themerex.net/offers/?utm_source=offers&utm_medium=click&utm_campaign=themeinstall',

			'theme_support_url'   => '//themerex.net/support/',

			'theme_download_url'  => '//themeforest.net/item/veil-wedding-event-photographer-wordpress-theme/45924539',        // Ancora

			'theme_video_url'     => '//www.youtube.com/channel/UCdIjRh7-lPVHqTTKpaf8PLA',   // Ancora

			'theme_privacy_url'   => '//ancorathemes.com/privacy-policy/',                   // Ancora

			'portfolio_url'       => '//themeforest.net/user/ancorathemes/portfolio',        // Ancora

			// Comma separated slugs of theme-specific categories (for get relevant news in the dashboard widget)
			// (i.e. 'children,kindergarten')
			'theme_categories'    => '',
		) );
	}
}


// Add/remove/change Theme Settings
if ( ! function_exists( 'veil_skin_setup_settings' ) ) {
	add_action( 'after_setup_theme', 'veil_skin_setup_settings', 1 );
	function veil_skin_setup_settings() {
		// Example: enable (true) / disable (false) thumbs in the prev/next navigation
		veil_storage_set_array( 'settings', 'thumbs_in_navigation', false );

		veil_storage_set_array2( 'required_plugins', 'woocommerce', 'install', true);
		veil_storage_set_array2( 'required_plugins', 'ti-woocommerce-wishlist', 'install', true);
		veil_storage_set_array2( 'required_plugins', 'elegro-payment', 'install', true);
		veil_storage_set_array2( 'required_plugins', 'the-events-calendar', 'install', true);
	}
}



//--------------------------------------------
// SKIN FONTS
//--------------------------------------------
if ( ! function_exists( 'veil_skin_setup_fonts' ) ) {
	add_action( 'after_setup_theme', 'veil_skin_setup_fonts', 1 );
	function veil_skin_setup_fonts() {
		// Fonts to load when theme start
		// It can be:
		// - Google fonts (specify name, family and styles)
		// - Adobe fonts (specify name, family and link URL)
		// - uploaded fonts (specify name, family), placed in the folder css/font-face/font-name inside the skin folder
		// Attention! Font's folder must have name equal to the font's name, with spaces replaced on the dash '-'
		// example: font name 'TeX Gyre Termes', folder 'TeX-Gyre-Termes'
		veil_storage_set(
			'load_fonts', array(
				array(
					'name'   => 'DM Sans',
					'family' => 'sans-serif',
					'link'   => '',
					'styles' => 'ital,wght@0,400;0,500;0,700;1,400;1,500;1,700'
				),
				array(
					'name'   => 'span',
					'family' => 'serif',
					'link'   => 'https://use.typekit.net/mdw1mbk.css',
					'styles' => ''
				),
			)
		);

		// Characters subset for the Google fonts. Available values are: latin,latin-ext,cyrillic,cyrillic-ext,greek,greek-ext,vietnamese
		veil_storage_set( 'load_fonts_subset', 'latin,latin-ext' );

		// Settings of the main tags.
		// Default value of 'font-family' may be specified as reference to the array $load_fonts (see above)
		// or as comma-separated string.
		// In the second case (if 'font-family' is specified manually as comma-separated string):
		//    1) Font name with spaces in the parameter 'font-family' will be enclosed in the quotes and no spaces after comma!
		//    2) If font-family inherit a value from the 'Main text' - specify 'inherit' as a value
		// example:
		// Correct:   'font-family' => veil_get_load_fonts_family_string( $load_fonts[0] )
		// Correct:   'font-family' => 'Roboto,sans-serif'
		// Correct:   'font-family' => '"PT Serif",sans-serif'
		// Incorrect: 'font-family' => 'Roboto, sans-serif'
		// Incorrect: 'font-family' => 'PT Serif,sans-serif'

		$font_description = esc_html__( 'Font settings for the %s of the site. To ensure that the elements scale properly on mobile devices, please use only the following units: "rem", "em" or "ex"', 'veil' );

		veil_storage_set(
			'theme_fonts', array(
				'p'       => array(
					'title'           => esc_html__( 'Main text', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'main text', 'veil' ) ),
					'font-family'     => '"DM Sans",sans-serif',
					'font-size'       => '1rem',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.647em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0em',
					'margin-bottom'   => '1.6em',
				),
				'post'    => array(
					'title'           => esc_html__( 'Article text', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'article text', 'veil' ) ),
					'font-family'     => '',			// Example: '"PR Serif",serif',
					'font-size'       => '',			// Example: '1.286rem',
					'font-weight'     => '',			// Example: '400',
					'font-style'      => '',			// Example: 'normal',
					'line-height'     => '',			// Example: '1.75em',
					'text-decoration' => '',			// Example: 'none',
					'text-transform'  => '',			// Example: 'none',
					'letter-spacing'  => '',			// Example: '',
					'margin-top'      => '',			// Example: '0em',
					'margin-bottom'   => '',			// Example: '1.4em',
				),
				'h1'      => array(
					'title'           => esc_html__( 'Heading 1', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H1', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '3.353em',
					'font-weight'     => '300',
					'font-style'      => 'normal',
					'line-height'     => '1em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '-1.71px',
					'margin-top'      => '1.15em',
					'margin-bottom'   => '0.38em',
				),
				'h2'      => array(
					'title'           => esc_html__( 'Heading 2', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H2', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '2.765em',
					'font-weight'     => '300',
					'font-style'      => 'normal',
					'line-height'     => '1.021em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.81em',
					'margin-bottom'   => '0.45em',
				),
				'h3'      => array(
					'title'           => esc_html__( 'Heading 3', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H3', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '2.059em',
					'font-weight'     => '300',
					'font-style'      => 'normal',
					'line-height'     => '1.086em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.16em',
					'margin-bottom'   => '0.63em',
				),
				'h4'      => array(
					'title'           => esc_html__( 'Heading 4', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H4', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '1.647em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.214em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.49em',
					'margin-bottom'   => '0.65em',
				),
				'h5'      => array(
					'title'           => esc_html__( 'Heading 5', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H5', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '1.412em',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.208em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '1.55em',
					'margin-bottom'   => '0.84em',
				),
				'h6'      => array(
					'title'           => esc_html__( 'Heading 6', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'tag H6', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '1.118em',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.474em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '2.4em',
					'margin-bottom'   => '0.85em',
				),
				'logo'    => array(
					'title'           => esc_html__( 'Logo text', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'text of the logo', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '1.7em',
					'font-weight'     => '300',
					'font-style'      => 'normal',
					'line-height'     => '1.25em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'button'  => array(
					'title'           => esc_html__( 'Buttons', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'buttons', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '18px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '22px',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'input'   => array(
					'title'           => esc_html__( 'Input fields', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'input fields, dropdowns and textareas', 'veil' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '16px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',     // Attention! Firefox don't allow line-height less then 1.5em in the select
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'info'    => array(
					'title'           => esc_html__( 'Post meta', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'post meta (author, categories, publish date, counters, share, etc.)', 'veil' ) ),
					'font-family'     => 'inherit',
					'font-size'       => '14px',  // Old value '13px' don't allow using 'font zoom' in the custom blog items
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
					'margin-top'      => '0.4em',
					'margin-bottom'   => '',
				),
				'menu'    => array(
					'title'           => esc_html__( 'Main menu', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'main menu items', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '16px',
					'font-weight'     => '600',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'submenu' => array(
					'title'           => esc_html__( 'Dropdown menu', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'dropdown menu items', 'veil' ) ),
					'font-family'     => 'span,serif',
					'font-size'       => '15px',
					'font-weight'     => '400',
					'font-style'      => 'normal',
					'line-height'     => '1.5em',
					'text-decoration' => 'none',
					'text-transform'  => 'none',
					'letter-spacing'  => '0px',
				),
				'other' => array(
					'title'           => esc_html__( 'Other', 'veil' ),
					'description'     => sprintf( $font_description, esc_html__( 'specific elements', 'veil' ) ),
					'font-family'     => '"DM Sans",sans-serif',
				),
			)
		);

		// Font presets
		veil_storage_set(
			'font_presets', array(
				'karla' => array(
								'title'  => esc_html__( 'Karla', 'veil' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Dancing Script',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
													// Google font
													array(
														'name'   => 'Sansita Swashed',
														'family' => 'fantasy',
														'link'   => '',
														'styles' => '300,400,700',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Dancing Script",fantasy',
														'font-size'       => '1.25rem',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
														'font-size'       => '4em',
													),
													'h2'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h3'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h4'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h5'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'h6'      => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'logo'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'button'  => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
													'submenu' => array(
														'font-family'     => '"Sansita Swashed",fantasy',
													),
												),
							),
				'roboto' => array(
								'title'  => esc_html__( 'Roboto', 'veil' ),
								'load_fonts' => array(
													// Google font
													array(
														'name'   => 'Noto Sans JP',
														'family' => 'serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
													// Google font
													array(
														'name'   => 'Merriweather',
														'family' => 'sans-serif',
														'link'   => '',
														'styles' => '300,300italic,400,400italic,700,700italic',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Noto Sans JP",serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Merriweather,sans-serif',
													),
												),
							),
				'garamond' => array(
								'title'  => esc_html__( 'Garamond', 'veil' ),
								'load_fonts' => array(
													// Adobe font
													array(
														'name'   => 'Europe',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
													// Adobe font
													array(
														'name'   => 'Sofia Pro',
														'family' => 'sans-serif',
														'link'   => 'https://use.typekit.net/qmj1tmx.css',
														'styles' => '',
													),
												),
								'theme_fonts' => array(
													'p'       => array(
														'font-family'     => '"Sofia Pro",sans-serif',
													),
													'post'    => array(
														'font-family'     => '',
													),
													'h1'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h2'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h3'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h4'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h5'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'h6'      => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'logo'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'button'  => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'input'   => array(
														'font-family'     => 'inherit',
													),
													'info'    => array(
														'font-family'     => 'inherit',
													),
													'menu'    => array(
														'font-family'     => 'Europe,sans-serif',
													),
													'submenu' => array(
														'font-family'     => 'Europe,sans-serif',
													),
												),
							),
			)
		);
	}
}


//--------------------------------------------
// COLOR SCHEMES
//--------------------------------------------
if ( ! function_exists( 'veil_skin_setup_schemes' ) ) {
	add_action( 'after_setup_theme', 'veil_skin_setup_schemes', 1 );
	function veil_skin_setup_schemes() {

		// Theme colors for customizer
		// Attention! Inner scheme must be last in the array below
		veil_storage_set(
			'scheme_color_groups', array(
				'main'    => array(
					'title'       => esc_html__( 'Main', 'veil' ),
					'description' => esc_html__( 'Colors of the main content area', 'veil' ),
				),
				'alter'   => array(
					'title'       => esc_html__( 'Alter', 'veil' ),
					'description' => esc_html__( 'Colors of the alternative blocks (sidebars, etc.)', 'veil' ),
				),
				'extra'   => array(
					'title'       => esc_html__( 'Extra', 'veil' ),
					'description' => esc_html__( 'Colors of the extra blocks (dropdowns, price blocks, table headers, etc.)', 'veil' ),
				),
				'inverse' => array(
					'title'       => esc_html__( 'Inverse', 'veil' ),
					'description' => esc_html__( 'Colors of the inverse blocks - when link color used as background of the block (dropdowns, blockquotes, etc.)', 'veil' ),
				),
				'input'   => array(
					'title'       => esc_html__( 'Input', 'veil' ),
					'description' => esc_html__( 'Colors of the form fields (text field, textarea, select, etc.)', 'veil' ),
				),
			)
		);

		veil_storage_set(
			'scheme_color_names', array(
				'bg_color'    => array(
					'title'       => esc_html__( 'Background color', 'veil' ),
					'description' => esc_html__( 'Background color of this block in the normal state', 'veil' ),
				),
				'bg_hover'    => array(
					'title'       => esc_html__( 'Background hover', 'veil' ),
					'description' => esc_html__( 'Background color of this block in the hovered state', 'veil' ),
				),
				'bd_color'    => array(
					'title'       => esc_html__( 'Border color', 'veil' ),
					'description' => esc_html__( 'Border color of this block in the normal state', 'veil' ),
				),
				'bd_hover'    => array(
					'title'       => esc_html__( 'Border hover', 'veil' ),
					'description' => esc_html__( 'Border color of this block in the hovered state', 'veil' ),
				),
				'text'        => array(
					'title'       => esc_html__( 'Text', 'veil' ),
					'description' => esc_html__( 'Color of the text inside this block', 'veil' ),
				),
				'text_dark'   => array(
					'title'       => esc_html__( 'Text dark', 'veil' ),
					'description' => esc_html__( 'Color of the dark text (bold, header, etc.) inside this block', 'veil' ),
				),
				'text_light'  => array(
					'title'       => esc_html__( 'Text light', 'veil' ),
					'description' => esc_html__( 'Color of the light text (post meta, etc.) inside this block', 'veil' ),
				),
				'text_link'   => array(
					'title'       => esc_html__( 'Link', 'veil' ),
					'description' => esc_html__( 'Color of the links inside this block', 'veil' ),
				),
				'text_hover'  => array(
					'title'       => esc_html__( 'Link hover', 'veil' ),
					'description' => esc_html__( 'Color of the hovered state of links inside this block', 'veil' ),
				),
				'text_link2'  => array(
					'title'       => esc_html__( 'Accent 2', 'veil' ),
					'description' => esc_html__( 'Color of the accented texts (areas) inside this block', 'veil' ),
				),
				'text_hover2' => array(
					'title'       => esc_html__( 'Accent 2 hover', 'veil' ),
					'description' => esc_html__( 'Color of the hovered state of accented texts (areas) inside this block', 'veil' ),
				),
				'text_link3'  => array(
					'title'       => esc_html__( 'Accent 3', 'veil' ),
					'description' => esc_html__( 'Color of the other accented texts (buttons) inside this block', 'veil' ),
				),
				'text_hover3' => array(
					'title'       => esc_html__( 'Accent 3 hover', 'veil' ),
					'description' => esc_html__( 'Color of the hovered state of other accented texts (buttons) inside this block', 'veil' ),
				),
			)
		);

		// Default values for each color scheme
		$schemes = array(

			// Color scheme: 'default'
			'default' => array(
				'title'    => esc_html__( 'Default', 'veil' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FBF7F4', //ok +
					'bd_color'         => '#E3D7CC', //ok +

					// Text and links colors
					'text'             => '#707376', //ok +
					'text_light'       => '#A5A6AA', //ok
					'text_dark'        => '#0E0D0E', //ok +
					'text_link'        => '#E74923', //ok +
					'text_hover'       => '#C9320E', //ok +
					'text_link2'       => '#D39C74', //ok +
					'text_hover2'      => '#B9835C', //ok +
					'text_link3'       => '#E2DBCF', //ok
					'text_hover3'      => '#D0C6B6', //ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#F9EEE5', //ok
					'alter_bg_hover'   => '#F9DEC8', //ok
					'alter_bd_color'   => '#E3D7CC', //ok +
					'alter_bd_hover'   => '#DCDCDC', //ok
					'alter_text'       => '#797C7F', //ok
					'alter_light'      => '#A5A6AA', //ok
					'alter_dark'       => '#0E0D0E', //ok +
					'alter_link'       => '#E74923', //ok +
					'alter_hover'      => '#C9320E', //ok +
					'alter_link2'      => '#D39C74', //ok +
					'alter_hover2'     => '#B9835C', //ok +
					'alter_link3'      => '#E2DBCF', //ok
					'alter_hover3'     => '#D0C6B6', //ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#040817', //ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#2D2F38',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#96999F', //ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //ok
					'extra_link'       => '#E74923', //ok +
					'extra_hover'      => '#ffffff', //ok
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //ok
					'input_bg_hover'   => 'transparent', //ok
					'input_bd_color'   => '#E3D7CC', //ok +
					'input_bd_hover'   => '#C4C8CC', //ok +
					'input_text'       => '#A5A6AA', //ok
					'input_light'      => '#A5A6AA', //ok
					'input_dark'       => '#0E0D0E', //ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#0E0D0E', //ok +
					'inverse_link'     => '#ffffff', //ok
					'inverse_hover'    => '#ffffff', //ok

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'dark'
			'dark'    => array(
				'title'    => esc_html__( 'Dark', 'veil' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#040817', //ok
					'bd_color'         => '#2D2F38', //ok

					// Text and links colors
					'text'             => '#B0B3BC', //ok
					'text_light'       => '#9497A0', //ok
					'text_dark'        => '#FCFCFC', //ok
					'text_link'        => '#E74923', //ok +
					'text_hover'       => '#C9320E', //ok +
					'text_link2'       => '#D39C74', //ok +
					'text_hover2'      => '#B9835C', //ok +
					'text_link3'       => '#E2DBCF', //ok
					'text_hover3'      => '#D0C6B6', //ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#0E173B', //ok +
					'alter_bg_hover'   => '#171717', //ok
					'alter_bd_color'   => '#2D2F38', //ok
					'alter_bd_hover'   => '#53535C', //ok
					'alter_text'       => '#B0B3BC', //ok
					'alter_light'      => '#9497A0', //ok
					'alter_dark'       => '#FCFCFC', //ok
					'alter_link'       => '#E74923', //ok +
					'alter_hover'      => '#C9320E', //ok +
					'alter_link2'      => '#D39C74', //ok +
					'alter_hover2'     => '#B9835C', //ok +
					'alter_link3'      => '#E2DBCF', //ok
					'alter_hover3'     => '#D0C6B6', //ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#171A21', //ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#2D2F38',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#9497A0',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#E74923', //ok +
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent', //ok
					'input_bg_hover'   => '#transparent', //ok
					'input_bd_color'   => '#2D2F38', //ok
					'input_bd_hover'   => '#2D2F38', //ok
					'input_text'       => '#B0B3BC', //ok
					'input_light'      => '#B0B3BC', //ok
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#FCFCFC', //ok
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#0E0D0E', //ok +
					'inverse_link'     => '#ffffff', //ok
					'inverse_hover'    => '#0E0D0E', //ok +

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'default'
			'light' => array(
				'title'    => esc_html__( 'Light', 'veil' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff', //ok
					'bd_color'         => '#E3D7CC', //ok +

					// Text and links colors
					'text'             => '#707376', //ok +
					'text_light'       => '#A5A6AA', //ok
					'text_dark'        => '#0E0D0E', //ok +
					'text_link'        => '#E74923', //ok +
					'text_hover'       => '#C9320E', //ok +
					'text_link2'       => '#D39C74', //ok +
					'text_hover2'      => '#B9835C', //ok +
					'text_link3'       => '#E2DBCF', //ok
					'text_hover3'      => '#D0C6B6', //ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FBF7F4', //ok +
					'alter_bg_hover'   => '#F9DEC8', //ok
					'alter_bd_color'   => '#E3D7CC', //ok +
					'alter_bd_hover'   => '#DCDCDC', //ok
					'alter_text'       => '#797C7F', //ok
					'alter_light'      => '#A5A6AA', //ok
					'alter_dark'       => '#0E0D0E', //ok +
					'alter_link'       => '#E74923', //ok +
					'alter_hover'      => '#C9320E', //ok +
					'alter_link2'      => '#D39C74', //ok 
					'alter_hover2'     => '#B9835C', //ok +
					'alter_link3'      => '#E2DBCF', //ok
					'alter_hover3'     => '#D0C6B6', //ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#040817', //ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#2D2F38',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#96999F', //ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //ok
					'extra_link'       => '#E74923', //ok +
					'extra_hover'      => '#ffffff', //ok
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //ok
					'input_bg_hover'   => 'transparent', //ok
					'input_bd_color'   => '#E3D7CC', //ok +
					'input_bd_hover'   => '#C4C8CC', //ok +
					'input_text'       => '#A5A6AA', //ok
					'input_light'      => '#A5A6AA', //ok
					'input_dark'       => '#0E0D0E', //ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#0E0D0E', //ok +
					'inverse_link'     => '#ffffff', //ok
					'inverse_hover'    => '#ffffff', //ok

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
			// Color scheme: 'default_bright'
			'default_bright' => array(
				'title'    => esc_html__( 'Default Bright', 'veil' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#FCF2F3', //ok +
					'bd_color'         => '#DED4D9', //ok +

					// Text and links colors
					'text'             => '#726E70', //ok +
					'text_light'       => '#91888D', //ok
					'text_dark'        => '#3C3B3B', //ok +
					'text_link'        => '#D60058', //ok +
					'text_hover'       => '#BD004D', //ok +
					'text_link2'       => '#E87B00', //ok +
					'text_hover2'      => '#DA8100', //ok +
					'text_link3'       => '#FFAEB0', //ok
					'text_hover3'      => '#F2A1A3', //ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#ffffff', //ok
					'alter_bg_hover'   => '#FCF2F3', //ok
					'alter_bd_color'   => '#DED4D9', //ok +
					'alter_bd_hover'   => '#DCDCDC', //ok
					'alter_text'       => '#797C7F', //ok
					'alter_light'      => '#91888D', //ok
					'alter_dark'       => '#3C3B3B', //ok +
					'alter_link'       => '#D60058', //ok +
					'alter_hover'      => '#BD004D', //ok +
					'alter_link2'      => '#E87B00', //ok +
					'alter_hover2'     => '#DA8100', //ok +
					'alter_link3'      => '#FFAEB0', //ok
					'alter_hover3'     => '#F2A1A3', //ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#000912', //ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#2D2F38',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#96999F', //ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //ok
					'extra_link'       => '#D60058', //ok +
					'extra_hover'      => '#ffffff', //ok
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //ok
					'input_bg_hover'   => 'transparent', //ok
					'input_bd_color'   => '#DED4D9', //ok +
					'input_bd_hover'   => '#C4C8CC', //ok +
					'input_text'       => '#91888D', //ok
					'input_light'      => '#91888D', //ok
					'input_dark'       => '#3C3B3B', //ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#3C3B3B', //ok +
					'inverse_link'     => '#ffffff', //ok
					'inverse_hover'    => '#ffffff', //ok

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'dark_bright'
			'dark_bright'    => array(
				'title'    => esc_html__( 'Dark Bright', 'veil' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#101010', //ok
					'bd_color'         => '#302F30', //ok

					// Text and links colors
					'text'             => '#9B9B9B', //ok
					'text_light'       => '#CECDCE', //ok
					'text_dark'        => '#FDFDFD', //ok
					'text_link'        => '#D60058', //ok +
					'text_hover'       => '#BD004D', //ok +
					'text_link2'       => '#E87B00', //ok +
					'text_hover2'      => '#DA8100', //ok +
					'text_link3'       => '#FFAEB0', //ok
					'text_hover3'      => '#F2A1A3', //ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#1A1919', //ok +
					'alter_bg_hover'   => '#151F46', //ok
					'alter_bd_color'   => '#302F30', //ok
					'alter_bd_hover'   => '#53535C', //ok
					'alter_text'       => '#9B9B9B', //ok
					'alter_light'      => '#CECDCE', //ok
					'alter_dark'       => '#FDFDFD', //ok
					'alter_link'       => '#D60058', //ok +
					'alter_hover'      => '#BD004D', //ok +
					'alter_link2'      => '#E87B00', //ok +
					'alter_hover2'     => '#DA8100', //ok +
					'alter_link3'      => '#FFAEB0', //ok
					'alter_hover3'     => '#F2A1A3', //ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#000912', //ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#302F30',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#CECDCE',
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff',
					'extra_link'       => '#D60058', //ok +
					'extra_hover'      => '#ffffff',
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => '#transparent', //ok
					'input_bg_hover'   => '#transparent', //ok
					'input_bd_color'   => '#302F30', //ok
					'input_bd_hover'   => '#302F30', //ok
					'input_text'       => '#9B9B9B', //ok
					'input_light'      => '#9B9B9B', //ok
					'input_dark'       => '#ffffff',

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#e36650',
					'inverse_bd_hover' => '#cb5b47',
					'inverse_text'     => '#FDFDFD', //ok
					'inverse_light'    => '#6f6f6f',
					'inverse_dark'     => '#3C3B3B', //ok +
					'inverse_link'     => '#ffffff', //ok
					'inverse_hover'    => '#3C3B3B', //ok +

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),

			// Color scheme: 'default_bright'
			'light_bright' => array(
				'title'    => esc_html__( 'Light Bright', 'veil' ),
				'internal' => true,
				'colors'   => array(

					// Whole block border and background
					'bg_color'         => '#ffffff', //ok
					'bd_color'         => '#DED4D9', //ok +

					// Text and links colors
					'text'             => '#726E70', //ok +
					'text_light'       => '#91888D', //ok
					'text_dark'        => '#3C3B3B', //ok +
					'text_link'        => '#D60058', //ok +
					'text_hover'       => '#BD004D', //ok +
					'text_link2'       => '#E87B00', //ok +
					'text_hover2'      => '#DA8100', //ok +
					'text_link3'       => '#FFAEB0', //ok
					'text_hover3'      => '#F2A1A3', //ok

					// Alternative blocks (sidebar, tabs, alternative blocks, etc.)
					'alter_bg_color'   => '#FCF2F3', //ok +
					'alter_bg_hover'   => '#ffffff', //ok
					'alter_bd_color'   => '#DED4D9', //ok +
					'alter_bd_hover'   => '#DCDCDC', //ok
					'alter_text'       => '#797C7F', //ok
					'alter_light'      => '#91888D', //ok
					'alter_dark'       => '#3C3B3B', //ok +
					'alter_link'       => '#D60058', //ok +
					'alter_hover'      => '#BD004D', //ok +
					'alter_link2'      => '#E87B00', //ok 
					'alter_hover2'     => '#DA8100', //ok +
					'alter_link3'      => '#FFAEB0', //ok
					'alter_hover3'     => '#F2A1A3', //ok

					// Extra blocks (submenu, tabs, color blocks, etc.)
					'extra_bg_color'   => '#000912', //ok +
					'extra_bg_hover'   => '#3f3d47',
					'extra_bd_color'   => '#2D2F38',
					'extra_bd_hover'   => '#575757',
					'extra_text'       => '#96999F', //ok
					'extra_light'      => '#afafaf',
					'extra_dark'       => '#ffffff', //ok
					'extra_link'       => '#D60058', //ok +
					'extra_hover'      => '#ffffff', //ok
					'extra_link2'      => '#80d572',
					'extra_hover2'     => '#8be77c',
					'extra_link3'      => '#ddb837',
					'extra_hover3'     => '#eec432',

					// Input fields (form's fields and textarea)
					'input_bg_color'   => 'transparent', //ok
					'input_bg_hover'   => 'transparent', //ok
					'input_bd_color'   => '#DED4D9', //ok +
					'input_bd_hover'   => '#C4C8CC', //ok +
					'input_text'       => '#91888D', //ok
					'input_light'      => '#91888D', //ok
					'input_dark'       => '#3C3B3B', //ok +

					// Inverse blocks (text and links on the 'text_link' background)
					'inverse_bd_color' => '#67bcc1',
					'inverse_bd_hover' => '#5aa4a9',
					'inverse_text'     => '#1d1d1d',
					'inverse_light'    => '#333333',
					'inverse_dark'     => '#3C3B3B', //ok +
					'inverse_link'     => '#ffffff', //ok
					'inverse_hover'    => '#ffffff', //ok

					// Additional (skin-specific) colors.
					// Attention! Set of colors must be equal in all color schemes.
					//---> For example:
					//---> 'new_color1'         => '#rrggbb',
					//---> 'alter_new_color1'   => '#rrggbb',
					//---> 'inverse_new_color1' => '#rrggbb',
				),
			),
		);
		veil_storage_set( 'schemes', $schemes );
		veil_storage_set( 'schemes_original', $schemes );

		// Add names of additional colors
		//---> For example:
		//---> veil_storage_set_array( 'scheme_color_names', 'new_color1', array(
		//---> 	'title'       => __( 'New color 1', 'veil' ),
		//---> 	'description' => __( 'Description of the new color 1', 'veil' ),
		//---> ) );


		// Additional colors for each scheme
		// Parameters:	'color' - name of the color from the scheme that should be used as source for the transformation
		//				'alpha' - to make color transparent (0.0 - 1.0)
		//				'hue', 'saturation', 'brightness' - inc/dec value for each color's component
		veil_storage_set(
			'scheme_colors_add', array(
				'bg_color_0'        => array(
					'color' => 'bg_color',
					'alpha' => 0,
				),
				'bg_color_02'       => array(
					'color' => 'bg_color',
					'alpha' => 0.2,
				),
				'bg_color_07'       => array(
					'color' => 'bg_color',
					'alpha' => 0.7,
				),
				'bg_color_08'       => array(
					'color' => 'bg_color',
					'alpha' => 0.8,
				),
				'bg_color_09'       => array(
					'color' => 'bg_color',
					'alpha' => 0.9,
				),
				'alter_bg_color_07' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.7,
				),
				'alter_bg_color_04' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.4,
				),
				'alter_bg_color_00' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0,
				),
				'alter_bg_color_02' => array(
					'color' => 'alter_bg_color',
					'alpha' => 0.2,
				),
				'alter_bd_color_02' => array(
					'color' => 'alter_bd_color',
					'alpha' => 0.2,
				),
                'alter_dark_015'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.15,
                ),
                'alter_dark_02'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.2,
                ),
                'alter_dark_05'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.5,
                ),
                'alter_dark_08'     => array(
                    'color' => 'alter_dark',
                    'alpha' => 0.8,
                ),
				'alter_link_02'     => array(
					'color' => 'alter_link',
					'alpha' => 0.2,
				),
				'alter_link_07'     => array(
					'color' => 'alter_link',
					'alpha' => 0.7,
				),
				'extra_bg_color_05' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.5,
				),
				'extra_bg_color_07' => array(
					'color' => 'extra_bg_color',
					'alpha' => 0.7,
				),
				'extra_link_02'     => array(
					'color' => 'extra_link',
					'alpha' => 0.2,
				),
				'extra_link_07'     => array(
					'color' => 'extra_link',
					'alpha' => 0.7,
				),
                'text_dark_003'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.03,
                ),
                'text_dark_005'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.05,
                ),
                'text_dark_008'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.08,
                ),
				'text_dark_015'      => array(
					'color' => 'text_dark',
					'alpha' => 0.15,
				),
				'text_dark_02'      => array(
					'color' => 'text_dark',
					'alpha' => 0.2,
				),
                'text_dark_03'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.3,
                ),
                'text_dark_05'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.5,
                ),
				'text_dark_07'      => array(
					'color' => 'text_dark',
					'alpha' => 0.7,
				),
                'text_dark_08'      => array(
                    'color' => 'text_dark',
                    'alpha' => 0.8,
                ),
                'text_link_007'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.07,
                ),
				'text_link_02'      => array(
					'color' => 'text_link',
					'alpha' => 0.2,
				),
                'text_link_03'      => array(
                    'color' => 'text_link',
                    'alpha' => 0.3,
                ),
				'text_link_04'      => array(
					'color' => 'text_link',
					'alpha' => 0.4,
				),
				'text_link_07'      => array(
					'color' => 'text_link',
					'alpha' => 0.7,
				),
				'text_link2_08'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.8,
                ),
                'text_link2_007'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.07,
                ),
				'text_link2_02'      => array(
					'color' => 'text_link2',
					'alpha' => 0.2,
				),
                'text_link2_03'      => array(
                    'color' => 'text_link2',
                    'alpha' => 0.3,
                ),
				'text_link2_05'      => array(
					'color' => 'text_link2',
					'alpha' => 0.5,
				),
                'text_link3_007'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.07,
                ),
				'text_link3_02'      => array(
					'color' => 'text_link3',
					'alpha' => 0.2,
				),
                'text_link3_03'      => array(
                    'color' => 'text_link3',
                    'alpha' => 0.3,
                ),
                'inverse_text_03'      => array(
                    'color' => 'inverse_text',
                    'alpha' => 0.3,
                ),
                'inverse_link_08'      => array(
                    'color' => 'inverse_link',
                    'alpha' => 0.8,
                ),
                'inverse_hover_08'      => array(
                    'color' => 'inverse_hover',
                    'alpha' => 0.8,
                ),
				'text_dark_blend'   => array(
					'color'      => 'text_dark',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'text_link_blend'   => array(
					'color'      => 'text_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
				'alter_link_blend'  => array(
					'color'      => 'alter_link',
					'hue'        => 2,
					'saturation' => -5,
					'brightness' => 5,
				),
			)
		);

		// Simple scheme editor: lists the colors to edit in the "Simple" mode.
		// For each color you can set the array of 'slave' colors and brightness factors that are used to generate new values,
		// when 'main' color is changed
		// Leave 'slave' arrays empty if your scheme does not have a color dependency
		veil_storage_set(
			'schemes_simple', array(
				'text_link'        => array(),
				'text_hover'       => array(),
				'text_link2'       => array(),
				'text_hover2'      => array(),
				'text_link3'       => array(),
				'text_hover3'      => array(),
				'alter_link'       => array(),
				'alter_hover'      => array(),
				'alter_link2'      => array(),
				'alter_hover2'     => array(),
				'alter_link3'      => array(),
				'alter_hover3'     => array(),
				'extra_link'       => array(),
				'extra_hover'      => array(),
				'extra_link2'      => array(),
				'extra_hover2'     => array(),
				'extra_link3'      => array(),
				'extra_hover3'     => array(),
			)
		);

		// Parameters to set order of schemes in the css
		veil_storage_set(
			'schemes_sorted', array(
				'color_scheme',
				'header_scheme',
				'menu_scheme',
				'sidebar_scheme',
				'footer_scheme',
			)
		);

		// Color presets
		veil_storage_set(
			'color_presets', array(
				'autumn' => array(
								'title'  => esc_html__( 'Autumn', 'veil' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	),
												'dark' => array(
																	'text_link'  => '#d83938',
																	'text_hover' => '#f2b232',
																	)
												)
							),
				'green' => array(
								'title'  => esc_html__( 'Natural Green', 'veil' ),
								'colors' => array(
												'default' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	),
												'dark' => array(
																	'text_link'  => '#75ac78',
																	'text_hover' => '#378e6d',
																	)
												)
							),
			)
		);
	}
}

// Activation methods
if ( ! function_exists( 'veil_skin_filter_activation_methods2' ) ) {
    add_filter( 'trx_addons_filter_activation_methods', 'veil_skin_filter_activation_methods2', 11, 1 );
    function veil_skin_filter_activation_methods2( $args ) {
        $args['elements_key'] = true;
        return $args;
    }
}

// Enqueue clone specific style
if ( ! function_exists( 'veil_clone_frontend_scripts' ) ) {
	add_action( 'wp_enqueue_scripts', 'veil_clone_frontend_scripts', 2150 );
	function veil_clone_frontend_scripts() {
		$veil_url = veil_get_file_url( veil_skins_get_current_skin_dir() . 'extra-styles.css' );
		if ( '' != $veil_url ) {
			wp_enqueue_style( 'veil-extra-styles-' . esc_attr( veil_skins_get_current_skin_name() ), $veil_url, array(), null );
		}
	}
}

// Custom styles
$veil_clone_style_path = veil_get_file_dir( veil_skins_get_current_skin_dir() . 'extra-styles.php' );
if ( ! empty( $veil_clone_style_path ) ) {
	require_once $veil_clone_style_path;
}

// Add new output types (layouts) in the shortcodes
if ( ! function_exists( 'veil_skin_setup_trx_addons_sc_type' ) ) {
    add_filter('trx_addons_sc_type', 'veil_skin_setup_trx_addons_sc_type', 11, 2);
    function veil_skin_setup_trx_addons_sc_type($list, $sc) {
        if ('trx_sc_layouts_menu' == $sc ) {
            $list['modern'] = 'Modern Burger';
        }
        return $list;
    }
}

// Theme init priorities:
// 3 - add/remove Theme Options elements
if ( ! function_exists( 'veil_clone_skin_theme_setup3' ) ) {
	add_action( 'after_setup_theme', 'veil_clone_skin_theme_setup3', 3 );
	function veil_clone_skin_theme_setup3() {
		veil_storage_set_array_after( 'options', 'remove_margins', array(
			'extra_bg_image' => array(
				"title" => esc_html__('Extra background image', 'veil'),
				"desc" => wp_kses_data( __('Select or upload background-image to display it in the page. Does not work for boxed body style.', 'veil') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'veil')
				),
				'dependency' => array(
					'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
				),
				"std" => '',
				'pro_only'   => VEIL_THEME_FREE,
				"type" => "image"
			),
			'extra_bg_image_size' => array(
				"title" => esc_html__('Extra background image size', 'veil'),
				"desc" => wp_kses_data( __('Use size contain (cover original).', 'veil') ),
				"override" => array(
					'mode' => 'page',
					'section' => esc_html__('Content', 'veil')
				),
				'dependency' => array(
					'body_style' => array( 'wide', 'fullwide', 'fullscreen' ),
				),
				"std" => 0,
				'pro_only'   => VEIL_THEME_FREE,
				"type" => "switch"
			),
			)
		);		
	}
}

if ( ! function_exists( 'veil_skin_filter_page_wrap_class' ) ) {
    add_action('veil_filter_page_wrap_class', 'veil_skin_filter_page_wrap_class');
    function veil_skin_filter_page_wrap_class($class) {
        $extra_bg_image = veil_get_theme_option('extra_bg_image');
        $extra_bg_image_size = veil_is_on(veil_get_theme_option('extra_bg_image_size'));
        $body_boxed_style = veil_get_theme_option( 'body_style' ) == 'boxed';
        if (!empty( $extra_bg_image ) && !$body_boxed_style ) {
            $custom_bg = ' ' . 'with_bg' .($extra_bg_image_size ? ' contain_size' : ''). ' ' . veil_add_inline_css_class('background-image: url(' . esc_url($extra_bg_image) . ');');
            $class = $class . $custom_bg;
        }
        return $class;
    }
}