<?php
/**
 * The Classic template to display the content
 *
 * Used for index/archive/search.
 *
 * @package VEIL
 * @since VEIL 1.0
 */

$veil_template_args = get_query_var( 'veil_template_args' );

if ( is_array( $veil_template_args ) ) {
	$veil_columns    = empty( $veil_template_args['columns'] ) ? 2 : max( 1, $veil_template_args['columns'] );
	$veil_blog_style = array( $veil_template_args['type'], $veil_columns );
    $veil_columns_class = veil_get_column_class( 1, $veil_columns, ! empty( $veil_template_args['columns_tablet']) ? $veil_template_args['columns_tablet'] : '', ! empty($veil_template_args['columns_mobile']) ? $veil_template_args['columns_mobile'] : '' );
} else {
	$veil_template_args = array();
	$veil_blog_style = explode( '_', veil_get_theme_option( 'blog_style' ) );
	$veil_columns    = empty( $veil_blog_style[1] ) ? 2 : max( 1, $veil_blog_style[1] );
    $veil_columns_class = veil_get_column_class( 1, $veil_columns );
}
$veil_expanded   = ! veil_sidebar_present() && veil_get_theme_option( 'expand_content' ) == 'expand';

$veil_post_format = get_post_format();
$veil_post_format = empty( $veil_post_format ) ? 'standard' : str_replace( 'post-format-', '', $veil_post_format );

?><div class="<?php
	if ( ! empty( $veil_template_args['slider'] ) ) {
		echo ' slider-slide swiper-slide';
	} else {
		echo ( veil_is_blog_style_use_masonry( $veil_blog_style[0] ) ? 'masonry_item masonry_item-1_' . esc_attr( $veil_columns ) : esc_attr( $veil_columns_class ) );
	}
?>"><article id="post-<?php the_ID(); ?>" data-post-id="<?php the_ID(); ?>"
	<?php
	post_class(
		'post_item post_item_container post_format_' . esc_attr( $veil_post_format )
				. ' post_layout_classic post_layout_classic_' . esc_attr( $veil_columns )
				. ' post_layout_' . esc_attr( $veil_blog_style[0] )
				. ' post_layout_' . esc_attr( $veil_blog_style[0] ) . '_' . esc_attr( $veil_columns )
	);
	veil_add_blog_animation( $veil_template_args );
	?>
>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$veil_hover      = ! empty( $veil_template_args['hover'] ) && ! veil_is_inherit( $veil_template_args['hover'] )
							? $veil_template_args['hover']
							: veil_get_theme_option( 'image_hover' );

	$veil_components = ! empty( $veil_template_args['meta_parts'] )
							? ( is_array( $veil_template_args['meta_parts'] )
								? $veil_template_args['meta_parts']
								: explode( ',', $veil_template_args['meta_parts'] )
								)
							: veil_array_get_keys_by_value( veil_get_theme_option( 'meta_parts' ) );

	veil_show_post_featured( apply_filters( 'veil_filter_args_featured',
		array(
			'thumb_size' => ! empty( $veil_template_args['thumb_size'] )
				? $veil_template_args['thumb_size']
				: veil_get_thumb_size(
					'classic' == $veil_blog_style[0]
						? ( strpos( veil_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $veil_columns > 2 ? 'big' : 'huge' )
								: ( $veil_columns > 2
									? ( $veil_expanded ? 'square' : 'square' )
									: ($veil_columns > 1 ? 'square' : ( $veil_expanded ? 'huge' : 'big' ))
									)
							)
						: ( strpos( veil_get_theme_option( 'body_style' ), 'full' ) !== false
								? ( $veil_columns > 2 ? 'masonry-big' : 'full' )
								: ($veil_columns === 1 ? ( $veil_expanded ? 'huge' : 'big' ) : ( $veil_columns <= 2 && $veil_expanded ? 'masonry-big' : 'masonry' ))
							)
			),
			'hover'      => $veil_hover,
			'meta_parts' => $veil_components,
			'no_links'   => ! empty( $veil_template_args['no_links'] ),
        ),
        'content-classic',
        $veil_template_args
    ) );

	// Title and post meta
	$veil_show_title = get_the_title() != '';
	$veil_show_meta  = count( $veil_components ) > 0 && ! in_array( $veil_hover, array( 'border', 'pull', 'slide', 'fade', 'info' ) );

	if ( $veil_show_title ) {
		?>
		<div class="post_header entry-header">
			<?php

			// Post meta
			if ( apply_filters( 'veil_filter_show_blog_meta', $veil_show_meta, $veil_components, 'classic' ) ) {
				if ( count( $veil_components ) > 0 ) {
					do_action( 'veil_action_before_post_meta' );
					veil_show_post_meta(
						apply_filters(
							'veil_filter_post_meta_args', array(
							'components' => join( ',', $veil_components ),
							'seo'        => false,
							'echo'       => true,
						), $veil_blog_style[0], $veil_columns
						)
					);
					do_action( 'veil_action_after_post_meta' );
				}
			}

			// Post title
			if ( apply_filters( 'veil_filter_show_blog_title', true, 'classic' ) ) {
				do_action( 'veil_action_before_post_title' );
				if ( empty( $veil_template_args['no_links'] ) ) {
					the_title( sprintf( '<h4 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h4>' );
				} else {
					the_title( '<h4 class="post_title entry-title">', '</h4>' );
				}
				do_action( 'veil_action_after_post_title' );
			}

			if( !in_array( $veil_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
				// More button
				if ( apply_filters( 'veil_filter_show_blog_readmore', ! $veil_show_title || ! empty( $veil_template_args['more_button'] ), 'classic' ) ) {
					if ( empty( $veil_template_args['no_links'] ) ) {
						do_action( 'veil_action_before_post_readmore' );
						veil_show_post_more_link( $veil_template_args, '<div class="more-wrap">', '</div>' );
						do_action( 'veil_action_after_post_readmore' );
					}
				}
			}
			?>
		</div><!-- .entry-header -->
		<?php
	}

	// Post content
	if( in_array( $veil_post_format, array( 'quote', 'aside', 'link', 'status' ) ) ) {
		ob_start();
		if (apply_filters('veil_filter_show_blog_excerpt', empty($veil_template_args['hide_excerpt']) && veil_get_theme_option('excerpt_length') > 0, 'classic')) {
			veil_show_post_content($veil_template_args, '<div class="post_content_inner">', '</div>');
		}
		// More button
		if(! empty( $veil_template_args['more_button'] )) {
			if ( empty( $veil_template_args['no_links'] ) ) {
				do_action( 'veil_action_before_post_readmore' );
				veil_show_post_more_link( $veil_template_args, '<div class="more-wrap">', '</div>' );
				do_action( 'veil_action_after_post_readmore' );
			}
		}
		$veil_content = ob_get_contents();
		ob_end_clean();
		veil_show_layout($veil_content, '<div class="post_content entry-content">', '</div><!-- .entry-content -->');
	}
	?>

</article></div><?php
// Need opening PHP-tag above, because <div> is a inline-block element (used as column)!
