<?php
/**
 * The default template to display the content
 *
 * Used for index/archive/search.
 *
 * @package VEIL
 * @since VEIL 1.0
 */

$veil_template_args = get_query_var( 'veil_template_args' );
$veil_columns = 1;
if ( is_array( $veil_template_args ) ) {
	$veil_columns    = empty( $veil_template_args['columns'] ) ? 1 : max( 1, $veil_template_args['columns'] );
	$veil_blog_style = array( $veil_template_args['type'], $veil_columns );
	if ( ! empty( $veil_template_args['slider'] ) ) {
		?><div class="slider-slide swiper-slide">
		<?php
	} elseif ( $veil_columns > 1 ) {
	    $veil_columns_class = veil_get_column_class( 1, $veil_columns, ! empty( $veil_template_args['columns_tablet']) ? $veil_template_args['columns_tablet'] : '', ! empty($veil_template_args['columns_mobile']) ? $veil_template_args['columns_mobile'] : '' );
		?>
		<div class="<?php echo esc_attr( $veil_columns_class ); ?>">
		<?php
	}
} else {
	$veil_template_args = array();
}
$veil_expanded    = ! veil_sidebar_present() && veil_get_theme_option( 'expand_content' ) == 'expand';
$veil_post_format = get_post_format();
$veil_post_format = empty( $veil_post_format ) ? 'standard' : str_replace( 'post-format-', '', $veil_post_format );
?>
<article id="post-<?php the_ID(); ?>" data-post-id="<?php the_ID(); ?>"
	<?php
	post_class( 'post_item post_item_container post_layout_excerpt post_format_' . esc_attr( $veil_post_format ) );
	veil_add_blog_animation( $veil_template_args );
	?>
>
	<?php

	// Sticky label
	if ( is_sticky() && ! is_paged() ) {
		?>
		<span class="post_label label_sticky"></span>
		<?php
	}

	// Featured image
	$veil_hover      = ! empty( $veil_template_args['hover'] ) && ! veil_is_inherit( $veil_template_args['hover'] )
							? $veil_template_args['hover']
							: veil_get_theme_option( 'image_hover' );
	$veil_components = ! empty( $veil_template_args['meta_parts'] )
							? ( is_array( $veil_template_args['meta_parts'] )
								? $veil_template_args['meta_parts']
								: array_map( 'trim', explode( ',', $veil_template_args['meta_parts'] ) )
								)
							: veil_array_get_keys_by_value( veil_get_theme_option( 'meta_parts' ) );
	veil_show_post_featured( apply_filters( 'veil_filter_args_featured',
		array(
			'no_links'   => ! empty( $veil_template_args['no_links'] ),
			'hover'      => $veil_hover,
			'meta_parts' => $veil_components,
			'thumb_size' => ! empty( $veil_template_args['thumb_size'] )
							? $veil_template_args['thumb_size']
							: veil_get_thumb_size( strpos( veil_get_theme_option( 'body_style' ), 'full' ) !== false
								? 'full'
								: ( $veil_expanded 
									? 'huge' 
									: 'big' 
									)
								),
		),
		'content-excerpt',
		$veil_template_args
	) );

	// Title and post meta
	$veil_show_title = get_the_title() != '';
	$veil_show_meta  = count( $veil_components ) > 0 && ! in_array( $veil_hover, array( 'border', 'pull', 'slide', 'fade', 'info' ) );

	if ( $veil_show_title ) {
		?>
		<div class="post_header entry-header">
			<?php
			// Post title
			if ( apply_filters( 'veil_filter_show_blog_title', true, 'excerpt' ) ) {
				do_action( 'veil_action_before_post_title' );
				if ( empty( $veil_template_args['no_links'] ) ) {
					the_title( sprintf( '<h3 class="post_title entry-title"><a href="%s" rel="bookmark">', esc_url( get_permalink() ) ), '</a></h3>' );
				} else {
					the_title( '<h3 class="post_title entry-title">', '</h3>' );
				}
				do_action( 'veil_action_after_post_title' );
			}
			?>
		</div><!-- .post_header -->
		<?php
	}

	// Post content
	if ( apply_filters( 'veil_filter_show_blog_excerpt', empty( $veil_template_args['hide_excerpt'] ) && veil_get_theme_option( 'excerpt_length' ) > 0, 'excerpt' ) ) {
		?>
		<div class="post_content entry-content">
			<?php

			// Post meta
			if ( apply_filters( 'veil_filter_show_blog_meta', $veil_show_meta, $veil_components, 'excerpt' ) ) {
				if ( count( $veil_components ) > 0 ) {
					do_action( 'veil_action_before_post_meta' );
					veil_show_post_meta(
						apply_filters(
							'veil_filter_post_meta_args', array(
								'components' => join( ',', $veil_components ),
								'seo'        => false,
								'echo'       => true,
							), 'excerpt', 1
						)
					);
					do_action( 'veil_action_after_post_meta' );
				}
			}

			if ( veil_get_theme_option( 'blog_content' ) == 'fullpost' ) {
				// Post content area
				?>
				<div class="post_content_inner">
					<?php
					do_action( 'veil_action_before_full_post_content' );
					the_content( '' );
					do_action( 'veil_action_after_full_post_content' );
					?>
				</div>
				<?php
				// Inner pages
				wp_link_pages(
					array(
						'before'      => '<div class="page_links"><span class="page_links_title">' . esc_html__( 'Pages:', 'veil' ) . '</span>',
						'after'       => '</div>',
						'link_before' => '<span>',
						'link_after'  => '</span>',
						'pagelink'    => '<span class="screen-reader-text">' . esc_html__( 'Page', 'veil' ) . ' </span>%',
						'separator'   => '<span class="screen-reader-text">, </span>',
					)
				);
			} else {
				// Post content area
				veil_show_post_content( $veil_template_args, '<div class="post_content_inner">', '</div>' );
			}

			// More button
			if ( apply_filters( 'veil_filter_show_blog_readmore',  ! isset( $veil_template_args['more_button'] ) || ! empty( $veil_template_args['more_button'] ), 'excerpt' ) ) {
				if ( empty( $veil_template_args['no_links'] ) ) {
					do_action( 'veil_action_before_post_readmore' );
					if ( veil_get_theme_option( 'blog_content' ) != 'fullpost' ) {
						veil_show_post_more_link( $veil_template_args, '<p>', '</p>' );
					} else {
						veil_show_post_comments_link( $veil_template_args, '<p>', '</p>' );
					}
					do_action( 'veil_action_after_post_readmore' );
				}
			}

			?>
		</div><!-- .entry-content -->
		<?php
	}
	?>
</article>
<?php

if ( is_array( $veil_template_args ) ) {
	if ( ! empty( $veil_template_args['slider'] ) || $veil_columns > 1 ) {
		?>
		</div>
		<?php
	}
}
